@@ -11,7 +11,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: lo_lowlevel.h,v 1.15 2005/12/29 20:08:26 nhumfrey Exp $
+ *  $Id: lo_lowlevel.h 70 2006-03-29 20:45:57Z nhumfrey $
  */
 
 #ifndef LO_LOWLEVEL_H
@@ -239,6 +239,13 @@ const char *lo_address_get_hostname(lo_address a);
  */
 const char *lo_address_get_port(lo_address a);
 
+/**
+ * \brief  Return the protocol of a lo_address object
+ *
+ * Returned value will be one of LO_UDP, LO_TCP or LO_UNIX.
+ */
+int lo_address_get_protocol(lo_address a);
+
 /**
  * \brief  Return a URL representing an OSC address
  *
@@ -459,6 +466,13 @@ int lo_server_get_socket_fd(lo_server s);
  */
 int lo_server_get_port(lo_server s);
 
+/**
+ * \brief  Return the protocol that the server is using.
+ *
+ * Returned value will be one of LO_UDP, LO_TCP or LO_UNIX.
+ */
+int lo_server_get_protocol(lo_server s);
+
 /**
  * \brief Return an OSC URL that can be used to contact the server.
  *
