@@ -11,7 +11,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: server.c,v 1.27 2006/01/26 15:00:28 nhumfrey Exp $
+ *  $Id: server.c 82 2007-03-09 20:43:39Z nhumfrey $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -123,15 +123,7 @@ int initWSock()
 
 lo_server lo_server_new(const char *port, lo_err_handler err_h)
 {
-#ifndef WIN32
-    if (port && *port == '/') {
-	return lo_server_new_with_proto(port, LO_UNIX, err_h);
-    } 
-    else 
-#endif
-    {
-	return lo_server_new_with_proto(port, LO_UDP, err_h);
-    }
+	return lo_server_new_with_proto(port, LO_DEFAULT, err_h);
 }
 
 lo_server lo_server_new_with_proto(const char *port, int proto,
@@ -146,6 +138,16 @@ lo_server lo_server_new_with_proto(const char *port, int proto,
     const char *service;
     char hostname[LO_HOST_SIZE];
 
+	// Set real protocol, if Default is requested
+	if (proto==LO_DEFAULT) {
+#ifndef WIN32
+		if (port && *port == '/') proto = LO_UNIX;
+		else 
+#endif
+		proto = LO_UDP;
+	}
+
+
 #ifdef WIN32
     if(!initWSock()) return NULL;
 #endif
@@ -185,7 +187,7 @@ lo_server lo_server_new_with_proto(const char *port, int proto,
 	}
 
 	sa.sun_family = AF_UNIX;
-	strncpy(sa.sun_path, port, 107);
+	strncpy(sa.sun_path, port, sizeof(sa.sun_path)-1);
 
 	if ((ret = bind(s->socket, (struct sockaddr *)&sa, sizeof(sa))) < 0) {
         int err = geterror();      
@@ -194,7 +196,7 @@ lo_server lo_server_new_with_proto(const char *port, int proto,
 	    lo_server_free(s);
 	    return NULL;
 	}
-
+	
 	s->path = strdup(port);
 
 	return s;
@@ -287,9 +289,12 @@ lo_server lo_server_new_with_proto(const char *port, int proto,
         lo_client_sockets.tcp = s->socket;
     }
 
-    /* Try it the IPV6 friendly way first */
+	/* Set hostname to empty string */
     hostname[0] = '\0';
-    for (it = ai; it; it = it->ai_next) {
+	
+#ifdef ENABLE_IPV6
+    /* Try it the IPV6 friendly way first */
+	for (it = ai; it; it = it->ai_next) {
 	if (getnameinfo(it->ai_addr, it->ai_addrlen, hostname,
 			sizeof(hostname), NULL, 0, NI_NAMEREQD) == 0) {
 	    break;
@@ -301,6 +306,8 @@ lo_server lo_server_new_with_proto(const char *port, int proto,
     if (hostname[0] == ':') {
 	hostname[0] = '\0';
     }
+#endif
+
 
     /* Fallback to the oldschool (i.e. more reliable) way */
     if (!hostname[0]) {
@@ -341,10 +348,23 @@ void lo_server_free(lo_server s)
 	lo_method it;
 	lo_method next;
 
-	if (s->socket != -1) close(s->socket);
-	freeaddrinfo(s->ai);
-	free(s->hostname);
-	free(s->path);
+	if (s->socket != -1) {
+		close(s->socket);
+		s->socket = -1;
+	}
+	if (s->ai) {
+		freeaddrinfo(s->ai);
+		s->ai=NULL;
+	}
+	if (s->hostname) {
+		free(s->hostname);
+		s->hostname = NULL;
+	}
+	if (s->path) {
+		if (s->protocol == LO_UNIX) unlink( s->path );
+		free(s->path);
+		s->path = NULL;
+	}
 	for (it = s->first; it; it = next) {
 	    next = it->next;
 	    free((char *)it->path);
@@ -685,7 +705,7 @@ static void dispatch_method(lo_server s, const char *path, char *types,
     if (src->host) free(src->port);
     src->host = strdup(hostname);
     src->port = strdup(portname);
-    src->proto = s->protocol;
+    src->protocol = s->protocol;
 
     for (it = s->first; it; it = it->next) {
 	/* If paths match or handler is wildcard */
@@ -1008,6 +1028,16 @@ int lo_server_get_port(lo_server s)
     return s->port;
 }
 
+int lo_server_get_protocol(lo_server s)
+{
+    if (!s) {
+	return -1;
+    }
+
+    return s->protocol;
+}
+
+
 char *lo_server_get_url(lo_server s)
 {
     int ret;
