@@ -11,7 +11,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: server_thread.c,v 1.8 2006/01/26 15:00:28 nhumfrey Exp $
+ *  $Id: server_thread.c 75 2007-03-08 19:01:44Z nhumfrey $
  */
 
 #include <unistd.h>
@@ -36,9 +36,15 @@
 static void thread_func(void *data);
 
 lo_server_thread lo_server_thread_new(const char *port, lo_err_handler err_h)
+{
+    return lo_server_thread_new_with_proto(port, LO_DEFAULT, err_h);
+}
+
+lo_server_thread lo_server_thread_new_with_proto(const char *port, int proto,
+				   lo_err_handler err_h)
 {
     lo_server_thread st = malloc(sizeof(struct _lo_server_thread));
-    st->s = lo_server_new(port, err_h);
+    st->s = lo_server_new_with_proto(port, proto, err_h);
     st->active = 0;
     st->done = 0;
 
@@ -51,6 +57,7 @@ lo_server_thread lo_server_thread_new(const char *port, lo_err_handler err_h)
     return st;
 }
 
+
 void lo_server_thread_free(lo_server_thread st)
 {
     if (st) {
